LocationTween class

A tween with a location values (latitude, Longitude).

Inheritance

Constructors

LocationTween({required IInterpolationServiceOptimized<ILatLng> interpolator})

Properties

bearing → double
no setter
begin ↔ ILatLng
The value this variable has at the beginning of the animation.
getter/setter pairoverride
end ↔ ILatLng
The value this variable has at the end of the animation.
getter/setter pairoverride
hashCode → int
The hash code for this object.
no setterinherited
isRipple → bool
no setter
isStopped → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

animate(Animation<double> parent) → Animation<ILatLng>
Returns a new Animation that is driven by the given animation but that takes on values determined by this object.
inherited
chain(Animatable<double> parent) → Animatable<ILatLng>
Returns a new Animatable whose value is determined by first evaluating the given parent and then evaluating this object at the result.
inherited
evaluate(Animation<double> animation) → ILatLng
The current value of this object for the given Animation.
inherited
lerp(double t) → ILatLng
Interpolate two locations with planet spherical calculations at the given animation clock value.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
swap(ILatLng from) → void
toString() → String
A string representation of this object.
inherited
transform(double t) → ILatLng
Returns the interpolated value for the current value of the given animation.
override

Operators

operator +(ILatLng end) → LocationTween
operator ==(Object other) → bool
The equality operator.
inherited